import java.sql.*;
import java.util.Properties;

/*
 * This Java source file was generated by the Gradle 'init' task.
 */
public class App {
    private static void runSelectTest(Connection conn, int times) throws SQLException {
        Statement st = conn.createStatement();
        ResultSet rs;
        for (int i = 0; i < times; i++) {
            rs = st.executeQuery("SELECT id, bar FROM foo");
            while (rs.next()) {
                rs.getInt(1);
                rs.getInt(2);
            }
            rs.close();
        }
        st.close();
    }

    private static void runUpdateTest(Connection conn, int times) throws SQLException {
        Statement st = conn.createStatement();
        int r;
        for (int i = 0; i < times; i++) {
            r = st.executeUpdate("UPDATE foo SET bar=bar+1 WHERE id=1");
            assert(r == 1);
        }
        st.close();
    }

    public static void main(String[] args) throws SQLException {
        String url = "jdbc:postgresql://localhost/t1";
        Properties props = new Properties();
        props.setProperty("user", "t1");
        String password = System.getenv("PG_T1_PASSWORD");
        if (password == null || password.isEmpty()) {
            System.out.println("Error: Please define PG_T1_PASSWORD environment variable");
            System.exit(1);
        }
        props.setProperty("password", password);
        props.setProperty("ssl", "false");
        Connection conn = DriverManager.getConnection(url, props);

        // warm up
        System.out.println("warming up JVM...");
        runSelectTest(conn, 3000);
        long start = System.nanoTime();
        runSelectTest(conn, 3000);
        long selectFinish = System.nanoTime();
        runUpdateTest(conn, 3000);
        long updateFinish = System.nanoTime();
        System.out.printf("select time cost: %.2fs\n", (selectFinish - start) / 1000000000.0);
        System.out.printf("update time cost: %.2fs\n", (updateFinish - selectFinish) / 1000000000.0);
    }
}
