extern crate postgres;
extern crate time;

use postgres::{Connection, TlsMode};
use postgres::params::{UserInfo, ConnectParams, ConnectTarget};
use time::PreciseTime;

const TIMES: i32 = 3000;

fn select_test(conn: &Connection) {
    for _ in 0..TIMES {
        conn.query("SELECT id, bar FROM foo", &[]).unwrap();
    }
}

fn update_test(conn: &Connection) {
    for _ in 0..TIMES {
        conn.execute("UPDATE foo SET bar=bar+1 WHERE id=1", &[]).unwrap();
    }
}

fn main() {
    let params = ConnectParams {
        target: ConnectTarget::Tcp(String::from("localhost")),
        port: None,
        user: Some(UserInfo {
            user: "t1".to_owned(),
            password: Some(String::from("fNfwREMqO69TB9YqE+/OzF5/k+s="))
        }),
        database: Some(String::from("t1")),
        options: vec![],
    };
    let conn = Connection::connect(params, TlsMode::None).unwrap();
    for row in &conn.query("SELECT id, bar FROM foo", &[]).unwrap() {
        let id_: i32 = row.get("id");
        let bar: i32 = row.get("bar");
        println!("id={} bar={}", id_, bar);
    }
    let start = PreciseTime::now();
    select_test(&conn);
    let end = PreciseTime::now();
    println!("{}", start.to(end));

    let start = PreciseTime::now();
    update_test(&conn);
    let end = PreciseTime::now();
    println!("{}", start.to(end));
}
